==> sdd.praapi-0.1.11-sources.jar: ar/com/sdd/praapi/model/DocumentIdentification.java <==
package ar.com.sdd.praapi.model;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

import java.io.Serializable;
import java.util.Objects;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class DocumentIdentification implements Serializable {

    private final String STANDARD_DEFAULT_VALUE = "GS1.JSON";
    private final String TYPE_VERSION_DEFAULT_VALUE = "2023-03-04";

    @JsonProperty("Standard")
    private String standard;

    @JsonProperty("TypeVersion")
    private String typeVersion;

    @JsonProperty("InstanceIdentifier")
    private String instanceIdentifier;

    @JsonProperty("Type")
    private String type;

    @JsonProperty("CreationDateAndTime")
    private String creationDateAndTime;

    public DocumentIdentification() {
    }

    public DocumentIdentification(String instanceIdentifier, String type, String creationDateAndTime) {
        this.standard = STANDARD_DEFAULT_VALUE;
        this.typeVersion = TYPE_VERSION_DEFAULT_VALUE;
        this.instanceIdentifier = instanceIdentifier;
        this.type = type;
        this.creationDateAndTime = creationDateAndTime;
    }

    public String getStandard() {
        return standard;
    }

    public void setStandard(String standard) {
        this.standard = standard;
    }

    public String getTypeVersion() {
        return typeVersion;
    }

    public void setTypeVersion(String typeVersion) {
        this.typeVersion = typeVersion;
    }

    public String getInstanceIdentifier() {
        return instanceIdentifier;
    }

    public void setInstanceIdentifier(String instanceIdentifier) {
        this.instanceIdentifier = instanceIdentifier;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getCreationDateAndTime() {
        return creationDateAndTime;
    }

    public void setCreationDateAndTime(String creationDateAndTime) {
        this.creationDateAndTime = creationDateAndTime;
    }

    @Override
    public String toString() {
        return "DocumentIdentification [" +
                ((standard != null) ? "standard='" + standard + "', " : "") +
                ((typeVersion != null) ? "typeVersion='" + typeVersion + "', " : "") +
                ((instanceIdentifier != null) ? "instanceIdentifier='" + instanceIdentifier + "', " : "") +
                ((type != null) ? "type='" + type + "', " : "") +
                ((creationDateAndTime != null) ? "creationDateAndTime='" + creationDateAndTime + "', " : "") +
                "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        DocumentIdentification that = (DocumentIdentification) o;
        return Objects.equals(standard, that.standard) && Objects.equals(typeVersion, that.typeVersion) && Objects.equals(instanceIdentifier, that.instanceIdentifier) && Objects.equals(type, that.type) && Objects.equals(creationDateAndTime, that.creationDateAndTime);
    }

    @Override
    public int hashCode() {
        return Objects.hash(standard, typeVersion, instanceIdentifier, type, creationDateAndTime);
    }
}

==> sdd.praapi-0.1.17-sources.jar: ar/com/sdd/praapi/model/DocumentIdentification.java <==
package ar.com.sdd.praapi.model;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;

import java.io.Serializable;
import java.util.Date;
import java.util.Objects;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown = true)
public class DocumentIdentification implements Serializable {

    private final String STANDARD_DEFAULT_VALUE = "GS1.JSON";
    private final String TYPE_VERSION_DEFAULT_VALUE = "2023-03-04";

    @JsonProperty("Standard")
    private String standard;

    @JsonProperty("TypeVersion")
    private String typeVersion;

    @JsonProperty("InstanceIdentifier")
    private String instanceIdentifier;

    @JsonProperty("Type")
    private String type;

    @JsonProperty("CreationDateAndTime")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd'T'HH:mm:ss.SSSXXX", timezone = "GMT-03:00")
    private Date creationDateAndTime;

    public DocumentIdentification() {
    }

    public DocumentIdentification(String instanceIdentifier, String type, Date creationDateAndTime) {
        this.standard = STANDARD_DEFAULT_VALUE;
        this.typeVersion = TYPE_VERSION_DEFAULT_VALUE;
        this.instanceIdentifier = instanceIdentifier;
        this.type = type;
        this.creationDateAndTime = creationDateAndTime;
    }

    public String getStandard() {
        return standard;
    }

    public void setStandard(String standard) {
        this.standard = standard;
    }

    public String getTypeVersion() {
        return typeVersion;
    }

    public void setTypeVersion(String typeVersion) {
        this.typeVersion = typeVersion;
    }

    public String getInstanceIdentifier() {
        return instanceIdentifier;
    }

    public void setInstanceIdentifier(String instanceIdentifier) {
        this.instanceIdentifier = instanceIdentifier;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public Date getCreationDateAndTime() {
        return creationDateAndTime;
    }

    public void setCreationDateAndTime(Date creationDateAndTime) {
        this.creationDateAndTime = creationDateAndTime;
    }

    @Override
    public String toString() {
        return "DocumentIdentification [" +
                ((standard != null) ? "standard='" + standard + "', " : "") +
                ((typeVersion != null) ? "typeVersion='" + typeVersion + "', " : "") +
                ((instanceIdentifier != null) ? "instanceIdentifier='" + instanceIdentifier + "', " : "") +
                ((type != null) ? "type='" + type + "', " : "") +
                ((creationDateAndTime != null) ? "creationDateAndTime='" + creationDateAndTime + "', " : "") +
                "]";
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        DocumentIdentification that = (DocumentIdentification) o;
        return Objects.equals(standard, that.standard) && Objects.equals(typeVersion, that.typeVersion) && Objects.equals(instanceIdentifier, that.instanceIdentifier) && Objects.equals(type, that.type) && Objects.equals(creationDateAndTime, that.creationDateAndTime);
    }

    @Override
    public int hashCode() {
        return Objects.hash(standard, typeVersion, instanceIdentifier, type, creationDateAndTime);
    }
}
